/*
 * CheckCsp - A checker for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp program.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: main.cc,v 1.4 2002/06/18 14:02:12 jano Exp $
 *
 */


#include "main.h"



/*
 * Prints out help and exits.
 *
 * return: nothing.
 *
 */

void PrintHelpAndDie ()
{
	
	cout
		<< "Random Csp Checker, version "
		<< CspC::MajorVersion
		<< "."
		<< CspC::MinorVersion
		<< "."
		<< CspC::UpdateVersion
		<< ", Copyright (C) 1998-2002 J.I. van Hemert."
		<< endl
		<< "Compiled on " << __DATE__;

	if (CspC::DebuggingCode)
	{
		cout << " with debugging code.";
	}
	else
	{
		cout << " without debugging code.";
	}
	
	cout
		<< endl << "This program comes as-is and with ABSOLUTELY NO WARRANTY."
		<< endl << endl
		<< "Please check the README for more information on how to use this program"
		<< endl
		<< "and the accompanied source code."
		<< endl << endl
		<< "This program can be used to check a solution for a constraint satisfaction"
		<< endl
		<< "problem generated by the RandomCsp program."
		<< endl << endl
		<< "checkcsp <problemfile> <solutionfile>"
		<< endl;

	exit (0);
} // PrintHelp



/*
 * Load a solution from a file and return an array with all the values of the
 * variables.
 *
 * iFilename: filename to read from.
 * iNumberOfVariables: number of variables in the csp problem.
 * oSolution: array with enough space to store all the values of the variables (size=iNumberOfVariables).
 *
 * return: nothing, returns oSolution.
 *
 */

void LoadSolutionFromFile
(
	char const * const iFilename,
	NumberOfVariablesT const iNumberOfVariables,
	ValueT oSolution []
)
{
	unsigned int i = 0;
	char dummy;

	ifstream InputFile;

	InputFile.open (iFilename);

	if (!InputFile.is_open ())
	{
		cerr << "Error: could not open solution file: " << iFilename << "." << endl;
		exit (2);
	}

	do
	{
		if (i < iNumberOfVariables)
			InputFile >> oSolution [i];
		else
			InputFile >> dummy;
		i++;
	} while (!InputFile.eof () && (i < iNumberOfVariables + 3));

	if (i > iNumberOfVariables + 1)
	{
		cerr << "Error: solutions has more variables then problem does." << endl;
		exit (1);
	}

	if (i <= iNumberOfVariables)
	{
		cerr << "Error: solutions has less variables then problem does." << endl;
		exit (1);
	}

	InputFile.close ();

} // LoadSolutionFromFile



int main
(
	int argc,
	char * argv []
)
{
	ValueT * Solution;
	
	if (argc != 3)
		PrintHelpAndDie ();

	StaticCspC csp(argv[1]);

	Solution = new ValueT [csp.GetNumberOfVariables ()];

	LoadSolutionFromFile (argv[2], csp.GetNumberOfVariables (), Solution);

	cout << csp.GetNumberOfConflicts (Solution) << endl;

	delete Solution;

} // main



// eof main.cc
