/*
 * ErrorC - A general class for reporting errors.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: error.cc,v 1.3 2003/03/04 17:32:42 jvhemert Exp $
 *
 */


#include "error.h"

using namespace std;

#include <iostream>

/*
 * Constructor for ErrorC.
 *
 * iOwner: string that holds the name of the class that uses ErrorC.
 *
 * return: nothing.
 *
 */

ErrorC::ErrorC
(
	char const * const iOwner
)
{
	Owner = strdup (iOwner);

} // ErrorC::ErrorC



/*
 * Destructor for ErrorC.
 *
 * return: nothing.
 *
 */

ErrorC::~ErrorC ()
{
	free (Owner);

} // ErrorC::~ErrorC



/*
 * Causes an error to be printed to stderr.
 *
 * iError: string that is send to stderr.
 * iErrorType: type of error, determines wheter to terminate the program and
 * the exitvalue.
 *
 * return: nothing.
 *
 */

void const ErrorC::Give
(
	char const * const iError,
	ErrorTypeT const iErrorType
) const
{
	switch (iErrorType)
	{
		case error:
			cerr << "Error (" << Owner << "): " << iError << endl;
			exit(error);
			break;
		case ioerror:
			cerr << "I/O Error (" << Owner << "): " << iError << endl;
			exit(ioerror);
			break;
		case warning:
			cerr << "Warning (" << Owner << "): " << iError << endl;
			break;
		default:
			cerr << "Internal error (" << Owner << "): Errortype " << iErrorType << " not defined." << endl;
			exit (internalerror);
	}

} // ErrorC::Give



// eof error.cc
