/*
 * ModelERandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: model_e.h,v 1.4 2004/02/16 16:06:52 jvhemert Exp $
 *
 */


#ifndef _ModelERandomCspC_H
#define _ModelERandomCspC_H


#include "randomcsp3.h"
#include <cmath>


/**
 * This class is capable of producing Random Binary Constraint Satisfaction
 * Problems. The usage is quite simple. After the creation of a object of this
 * class with all the correct parameters, the InitRandomGenerator function
 * should be used to set the seeds for the randomgenerator. This has to be done
 * at least once. Then a problem can be generated with the ProduceProblem
 * function and a filename can be produced with the ProduceFileName function
 * The output is a binary csp instance created with model E.
 *
 * @memo Random Constraint Satisfaction Problems
 *
 * @author J.I. van Hemert
 * @version 1.4
 *
 */

class ModelERandomCspC: 
	public RandomCsp3C
{
	public:

		
		ModelERandomCspC
		(
			NumberOfVariablesT const iNumberOfVariables,
			DomainSizeT const iDomainSize,
			bool const iRandomDomainSize,
			TightnessT const iTightness
		): RandomCsp3C (iNumberOfVariables, iDomainSize, iRandomDomainSize, iTightness)
		{
		};
		
		/**
		 * Produce a constraint satisfaction method using ModelE.
		 *
		 * @memo Producing a Random CSP
		 *
		 * @return nothing.
		 * 
		 * @author J.I. van Hemert
		 * @version 1.2
		 *
		 */

		void const ProduceProblem ();

		void ProduceFileName (char * FileName)
		{
			strcat (FileName, "me_");
			RandomCsp3C::ProduceFileName(FileName);
		}

	protected:

	private:

}; // ModelERandomCspC


#endif

// eof model_e.h
