/*
 * ModelRBRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2003 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: model_rb.cc,v 1.2 2004/02/16 16:06:53 jvhemert Exp $
 *
 */


#include "model_rb.h"

#include <cmath>


void const ModelRBRandomCspC::ProduceProblem ()
{
	unsigned long int t, q;
	unsigned int i, j, x, y = 0;

	Reset ();

	for (i = 0; i <= GetNumberOfVariables () - 1; i++)
		if (IsRandomDomainSize ())
			SetDomainSize (i, (random() % GetGlobalDomainSize ()) + 1);
		else
			SetDomainSize (i, GetGlobalDomainSize ());

	/* double -> unsigned int = ugly code! */
	t = (unsigned long int) (GetConnectivity() * GetNumberOfVariables() * log((double) GetNumberOfVariables()));

	while (t > 0)
	{
		do
		{
			i = random() % GetNumberOfVariables ();
			j = random() % GetNumberOfVariables ();
		}
		while (i == j);


		if (!IsConstraint (i, j))
		{
			AddConstraint (i, j);

			/* double -> unsigned int = ugly code! */
			q = (unsigned long int) (GetTightness () * GetDomainSize (i) * GetDomainSize (j));

			while (q > 0)
			{
				x = random() % GetDomainSize (i);
				y = random() % GetDomainSize (j);

				if (!IsConflict (i, j, x, y))
				{
					AddConflict (i, j, x, y);

					q--;
				}
			}
		}

		t--; // WITH repitition
	}

} // ModelRBRandomCspC::ProduceProblem



// eof model_rb.cc
