/*
 * RandomCsp - A empty class for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998-2000 by J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * $Id: randomcsp4.cc,v 1.4 2000/12/22 16:14:44 jano Exp $
 *
 */


#include "randomcsp4.h"



RandomCsp4C::RandomCsp4C
(
		NumberOfVariablesT const iNumberOfVariables,
		DomainSizeT const iDomainSize,
		bool const iRandomDomainSize,
		TightnessT const iTightness,
		ConnectivityT const iConnectivity
):
	RandomCspA (iNumberOfVariables)
{

	RandomDomainSize = iRandomDomainSize;

	DomainSize = iDomainSize;
	if (DomainSize < 1)
		Error->Give ("Domainsize should be larger than 0.", Error->error);

	Tightness = iTightness;
	/*if ((Tightness < 0) || (Tightness > 1))
		Error->Give ("Tightness should be between 0 and 1.", Error->error);*/

	Connectivity = iConnectivity;
	/*if ((Connectivity < 0) || (Connectivity > 1))
		Error->Give ("Connectivity should be between 0 and 1.", Error->error);*/

} // RandomCsp4C::RandomCsp4C



RandomCsp4C::~RandomCsp4C ()
{
} // RandomCsp4C::~RandomCsp4C




void const RandomCsp4C::ProduceProblem ()
{
} // RandomCsp4C::ProduceProblem



void RandomCsp4C::ProduceFileName
(
	char * FileName
)
{
	char * Tmp;
	Tmp = new char [70];

#if defined (Linux)
	snprintf (Tmp, 30, "v%i_d%i", GetNumberOfVariables (), DomainSize);
#else
	sprintf (Tmp, "v%i_d%i", GetNumberOfVariables (), DomainSize);
#endif
	strcat (FileName, Tmp);

	if (RandomDomainSize)
		strcat (FileName, "_r");
	else
		strcat (FileName, "_c");

#if defined (Linux)
	snprintf (Tmp, 60, "_t%.10g_c%.10g_s%i.csp", Tightness, Connectivity, GetSeed());
#else
	sprintf (Tmp, "_t%.10g_c%.10g_s%i.csp", Tightness, Connectivity, GetSeed());
#endif

	strcat (FileName, Tmp);

	delete Tmp;
	
} // RandomCsp4C::ProduceFileName



// eof pprosser.cc
